ErrorHandelerFlutterEnum enum

Enum class for all the exceptions and statusCodes

Inheritance
Available extensions

Values

badRequestError → const ErrorHandelerFlutterEnum

400

timeOutError → const ErrorHandelerFlutterEnum

TimeOut exception

forbiddenError → const ErrorHandelerFlutterEnum

403

conflictError → const ErrorHandelerFlutterEnum

409

internalServerError → const ErrorHandelerFlutterEnum

500

serverNotSupportError → const ErrorHandelerFlutterEnum

501

serverUnavailableError → const ErrorHandelerFlutterEnum

503

serverGatewayTimeOut → const ErrorHandelerFlutterEnum

server Gateway TimeOut The server, acting as a gateway or proxy, did not receive a timely response from an upstream server

unAuthorizationError → const ErrorHandelerFlutterEnum

401

notFoundError → const ErrorHandelerFlutterEnum

404

noInternetError → const ErrorHandelerFlutterEnum

When Internet is not available

platformExceptionError → const ErrorHandelerFlutterEnum

Platform Exception

socketExceptionError → const ErrorHandelerFlutterEnum

SocketException ( When base Url is no longer active or Internet issue)

undefined → const ErrorHandelerFlutterEnum

useually thrown when exception caught in Catch block or statusCode/Exception not defined in enum or Unkown to the package

formatExceptionError → const ErrorHandelerFlutterEnum

Format Exception

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<ErrorHandelerFlutterEnum>
A constant List of the values in this enum, in order of their declaration.